@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: turba/displayobject.php,v 1.9.2.8 2003/01/03 12:48:56 jan Exp $
+ * $Horde: turba/displayobject.php,v 1.9.2.9 2003/07/03 17:55:51 jan Exp $
  *
  * Turba: Copyright 2000-2003 Charles J. Hagenbuch <chuck@horde.org>
  *
@@ -16,6 +16,11 @@ require_once TURBA_BASE . '/lib/Source.php';
 require_once TURBA_BASE . '/lib/ObjectView.php';
 
 $source = Horde::getFormData('source');
+if (empty($source)) {
+    header('Location: ' . Horde::applicationUrl($prefs->getValue('initial_page'), true));
+    exit;
+}
+
 $driver = &Turba_Source::singleton($source, $cfgSources[$source]);
 
 $object = $driver->getObject(Horde::getFormData('key'));
